// src/loaders/css-loader.ts
import { extname } from "path";
import { readFileSync } from "fs";
import { isDev, debug } from "tailwindcss-webpack-plugin-utils";
async function CssLoader(source) {
  this.cacheable(false);
  debug(`[css-loader]: transform ${this.resourcePath} start`);
  const callback = this.async();
  const { service, dirty } = this._compiler.$tailwind;
  await service.ensureInit();
  if (dirty.size && isDev()) {
    const { configFiles, files } = Array.from(dirty).reduce(
      (map, file) => {
        file === "config-file" || service.configDependencies.has(file) ? map.configFiles.push(file) : map.files.push(file);
        return map;
      },
      {
        configFiles: [],
        files: []
      }
    );
    if (configFiles.length) {
      await service.refresh();
    } else {
      service.updateChangedContent(
        files.map((file) => {
          return {
            content: readFileSync(file, "utf8"),
            extension: extname(file).slice(1)
          };
        })
      );
    }
    dirty.clear();
  }
  try {
    const result = await service.transformCSS(source);
    debug(`[css-loader]: transform ${this.resourcePath} success`);
    callback(null, result.css);
  } catch (err) {
    debug(`[css-loader]: transform ${this.resourcePath} err: 
${err}`);
    callback(err, `${source}
/* Error: ${err}*/`);
  }
}
export {
  CssLoader as default
};
